Rossiter-McLaughlin model class
====================================

The class *RcmL* implements the
analytical model presented by *Ohta et al. 2005*.
For an elliptical orbit, the class *RmcLell* can be used.

    - :ref:`rmclcirc`
    - :ref:`rmclell`

.. currentmodule:: PyAstronomy.modelSuite

.. _rmclcirc:

RmcL (circular orbit)
------------------------

.. autoclass:: RmcL
   :members:

.. _rmclell:

RmcLell (elliptical orbit)
----------------------------

.. autoclass:: RmcLell
   :members:
